@@ -24,7 +24,7 @@ if lib_path:
     lib_names = None
 elif os.name == 'nt':
     # Windows NT shared libraries
-    lib_names = ['gdal111', 'gdal110', 'gdal19', 'gdal18', 'gdal17']
+    lib_names = [str('gdal111'), str('gdal110'), str('gdal19'), str('gdal18'), str('gdal17')]
 elif os.name == 'posix':
     # *NIX library names.
     lib_names = ['gdal', 'GDAL', 'gdal1.11.0', 'gdal1.10.0', 'gdal1.9.0', 'gdal1.8.0', 'gdal1.7.0']
@@ -67,6 +67,7 @@ def std_call(func):
     else:
         return lgdal[func]
 
+
 # #### Version-information functions. ####
 
 # Returns GDAL library version information with the given key.
@@ -84,6 +85,7 @@ def gdal_full_version():
     "Returns the full GDAL version information."
     return _version_info('')
 
+
 version_regex = re.compile(r'^(?P<major>\d+)\.(?P<minor>\d+)(\.(?P<subminor>\d+))?')
 
 
@@ -94,6 +96,7 @@ def gdal_version_info():
         raise GDALException('Could not parse GDAL version string "%s"' % ver)
     return {key: m.group(key) for key in ('major', 'minor', 'subminor')}
 
+
 _verinfo = gdal_version_info()
 GDAL_MAJOR_VERSION = int(_verinfo['major'])
 GDAL_MINOR_VERSION = int(_verinfo['minor'])
@@ -107,6 +110,8 @@ CPLErrorHandler = CFUNCTYPE(None, c_int, c_int, c_char_p)
 
 def err_handler(error_class, error_number, message):
     logger.error('GDAL_ERROR %d: %s', error_number, message)
+
+
 err_handler = CPLErrorHandler(err_handler)
 
 
@@ -116,5 +121,6 @@ def function(name, args, restype):
     func.restype = restype
     return func
 
+
 set_error_handler = function('CPLSetErrorHandler', [CPLErrorHandler], CPLErrorHandler)
 set_error_handler(err_handler)
